@@ -102,17 +102,17 @@ public:
      * game in load/save and network operations. Change this between
      * games.
      */
-    explicit KGame(int cookie=42,QObject* parent=0);
+    explicit KGame(int cookie=42,QObject* parent=nullptr);
 
     /**
     * Destructs the game
     */
-    virtual ~KGame();
+    ~KGame() override;
 
     /**
      * Gives debug output of the game status
      */
-    void Debug() Q_DECL_OVERRIDE;
+    void Debug() override;
 
     /**
      * Game status - Use this to Control the game flow.
@@ -460,7 +460,7 @@ public:
      * @param sender
      * @param clientID the client from which we received the transmission - hardly used
      **/
-    void networkTransmission(QDataStream &stream, int msgid, quint32 receiver, quint32 sender, quint32 clientID) Q_DECL_OVERRIDE;
+    void networkTransmission(QDataStream &stream, int msgid, quint32 receiver, quint32 sender, quint32 clientID) override;
 
     /**
      * Returns a pointer to the KGame property handler
@@ -577,7 +577,7 @@ Q_SIGNALS:
     void signalSave(QDataStream &stream);
 
     /**
-     * Is emmited if a game with a different version cookie is loaded.
+     * Is emitted if a game with a different version cookie is loaded.
      * Normally this should result in an error. But maybe you do support
      * loading of older game versions. Here would be a good place to do a
      * conversion.
@@ -592,7 +592,7 @@ Q_SIGNALS:
     /**
      * We got an user defined update message. This is usually done
      * by a sendData in a inherited KGame Object which defines its
-     * own methods and has to syncronise them over the network.
+     * own methods and has to synchronize them over the network.
      * Reaction to this is usually a call to a KGame function.
      */
     void signalNetworkData(int msgid,const QByteArray& buffer, quint32 receiver, quint32 sender);
@@ -625,7 +625,7 @@ Q_SIGNALS:
 
 
     /**
-    * This signal is emmited if a player property changes its value and
+    * This signal is emitted if a player property changes its value and
     * the property is set to notify this change
     */
     void signalPropertyChanged(KGamePropertyBase *property, KGame *me);
@@ -641,7 +641,7 @@ Q_SIGNALS:
     void signalGameOver(int status, KPlayer *current, KGame *me);
 
     /**
-    * Is emmited after a client is successfully connected to the game.
+    * Is emitted after a client is successfully connected to the game.
     * The client id is the id of the new game client. An easy way to
     * check whether that's us is
     * \code
@@ -728,7 +728,7 @@ protected:
     * each game to make sense.
     *
     * Not overwriting this function will activate a default behaviour which
-    * will deactivate players until the @ref maxPlayers() numebr is reached
+    * will deactivate players until the @ref maxPlayers() number is reached
     * according to the KPlayer::networkPriority() value. Players with a low
     * value will be kicked out first. With equal priority players of the new
     * client will leave first. This means, not setting this value and not
@@ -767,7 +767,7 @@ protected:
     * @param list the optional list is the player list to be saved, default is playerList()
     *
     **/
-    void savePlayers(QDataStream &stream,KGamePlayerList *list=0);
+    void savePlayers(QDataStream &stream,KGamePlayerList *list=nullptr);
 
     /**
      * Prepare a player for being added. Put all data about a player into the
@@ -843,7 +843,7 @@ protected:
     virtual void negotiateNetworkGame(quint32 clientID);
 
     /**
-     * syncronise the random numbers with all network clients
+     * synchronize the random numbers with all network clients
      * not used by KGame - if it should be kept then as public method
      */
     void syncRandom();
